.. _cfdp:

====================================
CCSDS File Delivery Protocol (CFDP)
====================================

The majority of the CFDP components were moved to the dedicated `cfdp-py`_ library.
It is recommended to read its `dedicated documentation <https://cfdp-py.readthedocs.io/en/latest/>`_.

.. _cfdp-py: https://github.com/us-irs/cfdp-py
